@@ -1,5 +1,5 @@
 """
-wia_scan 0.6.1
+wia_scan 0.7.0
 ==========
 
 A simple utility for using document scanners that support Windows Image Acquisition (WIA) and is
@@ -10,7 +10,15 @@ See https://github.com/JonasZehn/python_wia_scan for usage and source.
 
 """
 
-__version__ = "0.6.1"
+__version__ = "0.7.0"
 
-from .scan_functions import *
-from .scan_main import *
+from .core import *
+from .main import *
+
+del tempfile
+del sys
+del os
+del datetime
+del docopt
+del win32com
+del PILImage
